use crate::login_window::LoginWindow;

use gtk4 as gtk;
use gtk::{glib, gio, prelude::*, subclass::prelude::*};

mod imp {
    use super::*;
    
    #[derive(Debug)]
    pub struct Application {
        pub settings: gio::Settings,
    }

    impl Default for Application {
        fn default() -> Self {
            Self {
                settings: gio::Settings::new(crate::APP_ID)
            }
        }
    }

    #[glib::object_subclass]
    impl ObjectSubclass for Application {
        const NAME: &'static str = "Application";
        type Type = super::Application;
        type ParentType = gtk::Application;
    }

    impl ApplicationImpl for Application {
        fn activate(&self) {
            let login_window = LoginWindow::new(&self.obj());
            login_window.present();
        }
    }

    impl ObjectImpl for Application {}
    impl GtkApplicationImpl for Application {}
}

glib::wrapper! {
    pub struct Application(ObjectSubclass<imp::Application>)
        @extends gtk::Application, gio::Application,
        @implements gio::ActionMap, gio::ActionGroup;
}

impl Application {
    pub fn new(app_id: &str) -> Self {
        glib::Object::builder().property("application-id", app_id).build()
    }
}
